pub struct TableRow {
pub cells: Vec<TableCell>,
pub height: RowHeight,
pub is_header: bool,
}Expand description
A row in a table with optional exact/minimum height.
Fields
cells: Vec<TableCell>height: RowHeightis_header: boolImplementations
Sourceimpl TableRow
impl TableRow
pub fn new(cells: Vec<TableCell>) -> Self
Sourcepub fn plain(cells: Vec<String>) -> Self
pub fn plain(cells: Vec<String>) -> Self
Constructs a row from plain strings — convenience for simple tables.
Sourcepub fn height_exact(self, mm: f64) -> Self
pub fn height_exact(self, mm: f64) -> Self
Sets an exact height for this row in mm.
Sourcepub fn height_at_least(self, mm: f64) -> Self
pub fn height_at_least(self, mm: f64) -> Self
Sets a minimum height for this row in mm.